webbpsf\_ext.webbpsf\_ext\_core.MIRI\_ext
=========================================

.. currentmodule:: webbpsf_ext.webbpsf_ext_core

.. autoclass:: MIRI_ext
   :members:
   :inherited-members:
   :show-inheritance:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~MIRI_ext.__init__
      ~MIRI_ext.calc_datacube
      ~MIRI_ext.calc_datacube_fast
      ~MIRI_ext.calc_psf
      ~MIRI_ext.calc_psf_from_coeff
      ~MIRI_ext.calc_psfs_grid
      ~MIRI_ext.calc_psfs_sgd
      ~MIRI_ext.display
      ~MIRI_ext.drift_opd
      ~MIRI_ext.gen_mask_image
      ~MIRI_ext.gen_psf_coeff
      ~MIRI_ext.gen_save_name
      ~MIRI_ext.gen_wfedrift_coeff
      ~MIRI_ext.gen_wfefield_coeff
      ~MIRI_ext.gen_wfemask_coeff
      ~MIRI_ext.get_IFU_wavelengths
      ~MIRI_ext.get_opd_file_full_path
      ~MIRI_ext.get_opd_info
      ~MIRI_ext.get_optical_system
      ~MIRI_ext.get_wfe
      ~MIRI_ext.interpolate_was_opd
      ~MIRI_ext.load_wss_opd
      ~MIRI_ext.load_wss_opd_by_date
      ~MIRI_ext.plot_bandpass
      ~MIRI_ext.psf_grid
      ~MIRI_ext.set_position_from_aperture_name
      ~MIRI_ext.visualize_wfe_budget
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~MIRI_ext.aperturename
      ~MIRI_ext.band
      ~MIRI_ext.bandpass
      ~MIRI_ext.detector
      ~MIRI_ext.detector_list
      ~MIRI_ext.detector_position
      ~MIRI_ext.fastaxis
      ~MIRI_ext.filter
      ~MIRI_ext.filter_list
      ~MIRI_ext.fov_pix
      ~MIRI_ext.image_mask
      ~MIRI_ext.is_coron
      ~MIRI_ext.is_slitspec
      ~MIRI_ext.mode
      ~MIRI_ext.name
      ~MIRI_ext.ndeg
      ~MIRI_ext.npsf
      ~MIRI_ext.options
      ~MIRI_ext.oversample
      ~MIRI_ext.pixelscale
      ~MIRI_ext.pupil
      ~MIRI_ext.pupil_mask
      ~MIRI_ext.pupilopd
      ~MIRI_ext.quick
      ~MIRI_ext.save_dir
      ~MIRI_ext.save_name
      ~MIRI_ext.siaf_ap
      ~MIRI_ext.slowaxis
      ~MIRI_ext.telescope
      ~MIRI_ext.use_fov_pix_plus1
      ~MIRI_ext.wave_fit
      ~MIRI_ext.include_ote_field_dependence
      ~MIRI_ext.image_mask_list
      ~MIRI_ext.pupil_mask_list
   
   